@@ -1,5 +1,5 @@
 # TrimPy: A basic API implementation for Trimlight Select systems,
-# Copyright (C) 2021 Ethan Dye
+# Copyright (C) 2021-2022 Ethan Dye
 #
 # TrimPy is free software: you can redistribute it and/or modify
 # it under the terms of the GNU General Public License version 3 as
@@ -20,9 +20,9 @@ from enum import Enum
 # patterns correspond to. Custom patterns can also be accessed using this same
 # format, they just come after the builtin patterns.
 class Pattern(Enum):
-    NEW_YEARS = 1
-    VALENTINES = 2
-    ST_PATRICKS = 3
+    NEW_YEAR = 1
+    ST_VALENTINE = 2
+    ST_PATRICK = 3
     MOTHERS_DAY = 4
     INDEPENDENCE_DAY = 5
     DEFAULT = 6
